@@ -16,4 +16,4 @@
 
 #include <sys/types.h>
 
-int mgetgroups (const char *username, gid_t gid, GETGROUPS_T **groups);
+int mgetgroups (const char *username, gid_t gid, gid_t **groups);
