@@ -24,6 +24,7 @@
 
 #include "system.h"
 #include "error.h"
+#include "hard-locale.h"
 #include "linebuffer.h"
 #include "memcasecmp.h"
 #include "quote.h"
@@ -208,7 +209,7 @@ Note, comparisons honor the rules specified by `LC_COLLATE'.\n\
 If the input is not sorted and some lines cannot be joined, a\n\
 warning message will be given.\n\
 "), stdout);
-      emit_bug_reporting_address ();
+      emit_ancillary_info ();
     }
   exit (status);
 }
