@@ -67,7 +67,7 @@ This program is useful only when run by root (user ID zero).\n\
 "), stdout);
       fputs (HELP_OPTION_DESCRIPTION, stdout);
       fputs (VERSION_OPTION_DESCRIPTION, stdout);
-      emit_bug_reporting_address ();
+      emit_ancillary_info ();
     }
   exit (status);
 }
@@ -110,7 +110,7 @@ main (int argc, char **argv)
                       error (EXIT_FAILURE, 0, _("invalid group %s"),
                              quote (gr));
                     if (n_gids == n_gids_allocated)
-                      gids = x2nrealloc (gids, &n_gids_allocated, sizeof *gids);
+                      gids = X2NREALLOC (gids, &n_gids_allocated);
                     gids[n_gids++] = tmp_ul;
 
                     if (*ptr == '\0')
@@ -181,7 +181,7 @@ main (int argc, char **argv)
       {
         int n = mgetgroups (pwd->pw_name, pwd->pw_gid, &gids);
         if (n <= 0)
-          error (1, errno, _("failed to get groups for user %s"),
+          error (EXIT_FAILURE, errno, _("failed to get groups for user %s"),
                  quote (pwd->pw_name));
         n_gids = n;
       }
@@ -210,13 +210,7 @@ main (int argc, char **argv)
     execvp (*cmd, cmd);
     exit_status = (errno == ENOENT ? EXIT_ENOENT : EXIT_CANNOT_INVOKE);
 
-    error (0, errno, _("cannot run command %s"), quote (*cmd));
+    error (0, errno, _("failed to run command %s"), quote (*cmd));
     exit (exit_status);
   }
 }
-
-/*
- * Local variables:
- *  indent-tabs-mode: nil
- * End:
- */
